# eric7.EricNetwork.EricSslInfoWidget

Module implementing a widget to show SSL information.

### Global Attributes

None

### Classes

EricSslInfoWidget | Class implementing a widget to show SSL certificate infos.

### Functions

None

## EricSslInfoWidget

Class implementing a widget to show SSL certificate infos.

### Derived from

QMenu

### Class Attributes

None

### Class Methods

None

### Methods

EricSslInfoWidget | Constructor
__showCertificateInfos | Private slot to show certificate information.
accept | Public method to accept the widget.
showAt | Public method to show the widget.

### Static Methods

None

#### EricSslInfoWidget (Constructor)

EricSslInfoWidget(url, configuration, parent=None)

Constructor

url (QUrl)
  URL to show SSL info for
configuration (QSslConfiguration)
  SSL configuration
parent (QWidget)
  reference to the parent widget

#### EricSslInfoWidget.__showCertificateInfos

__showCertificateInfos()

Private slot to show certificate information.

#### EricSslInfoWidget.accept

accept()

Public method to accept the widget.

#### EricSslInfoWidget.showAt

showAt(pos)

Public method to show the widget.

pos (QPoint)
  position to show at

Up